@@ -13,24 +13,24 @@ var searchData=
   ['tab_5fwrap',['Tab_Wrap',['../classwx_grid.html#acd42a9c04692a5ef6b0a4997c4e9a77ea52b3bd87557d9d5cb7e5abfdf010717f',1,'wxGrid']]],
   ['tabbehaviour',['TabBehaviour',['../classwx_grid.html#acd42a9c04692a5ef6b0a4997c4e9a77e',1,'wxGrid']]],
   ['tabhittest',['TabHitTest',['../classwx_aui_tab_container.html#a4b30e80abdde9b3e4a83127ef9eb24d6',1,'wxAuiTabContainer']]],
-  ['tabmdi_2eh',['tabmdi.h',['../tabmdi_8h.html',1,'']]],
   ['takedata',['TakeData',['../classwx_custom_data_object.html#a133a6a8044d298b68b50945c422ae4a8',1,'wxCustomDataObject']]],
   ['targetfromselection',['TargetFromSelection',['../classwx_styled_text_ctrl.html#ab943ccce1bf3a135bea42becef9d5653',1,'wxStyledTextCtrl']]],
   ['tarstrm_2eh',['tarstrm.h',['../tarstrm_8h.html',1,'']]],
   ['taskbar_2eh',['taskbar.h',['../taskbar_8h.html',1,'']]],
+  ['taskbarbutton_2eh',['taskbarbutton.h',['../taskbarbutton_8h.html',1,'']]],
   ['tchar_5fstr',['tchar_str',['../classwx_string.html#aea75e9a0639470adcc2c8260156038e3',1,'wxString']]],
   ['tell',['Tell',['../classwx_f_file.html#a1b84187b39d443c83f37727a4e69051f',1,'wxFFile::Tell()'],['../classwx_temp_file.html#a7b930c371b6546950903949f6000dc13',1,'wxTempFile::Tell()'],['../classwx_file.html#afc7eaf653255bf2db25f20626d3eedb1',1,'wxFile::Tell()'],['../classwx_media_ctrl.html#aa859c2a3157cecc823f853540a9097a2',1,'wxMediaCtrl::Tell()'],['../classwx_stream_buffer.html#ae95ffab896829ec7d2e8b821f42c0ab5',1,'wxStreamBuffer::Tell()']]],
   ['telli',['TellI',['../classwx_input_stream.html#aece5e9ece88100f15fa91802b005ef4b',1,'wxInputStream']]],
   ['tello',['TellO',['../classwx_output_stream.html#acb127540592e6b5a3e8787329eb696a4',1,'wxOutputStream']]],
   ['testdestroy',['TestDestroy',['../classwx_thread.html#a9a3acec44b06b2a2430c5659991a3eac',1,'wxThread']]],
-  ['text',['Text',['../classwx_u_i_action_simulator.html#af8daaf3d87f184e2dec185b820eab9b3',1,'wxUIActionSimulator']]],
+  ['text',['Text',['../classwx_busy_info_flags.html#aaf0327e70e6902b53c786f0ff93d679b',1,'wxBusyInfoFlags::Text()'],['../classwx_u_i_action_simulator.html#af8daaf3d87f184e2dec185b820eab9b3',1,'wxUIActionSimulator::Text()']]],
   ['textcompleter_2eh',['textcompleter.h',['../textcompleter_8h.html',1,'']]],
   ['textctrl_2eh',['textctrl.h',['../textctrl_8h.html',1,'']]],
   ['textdlg_2eh',['textdlg.h',['../textdlg_8h.html',1,'']]],
   ['textentry_2eh',['textentry.h',['../textentry_8h.html',1,'']]],
   ['textfile_2eh',['textfile.h',['../textfile_8h.html',1,'']]],
   ['textheight',['TextHeight',['../classwx_styled_text_ctrl.html#ae955348ccf4efd231357c6d96f299589',1,'wxStyledTextCtrl']]],
-  ['textindent',['TextIndent',['../structwx_combo_ctrl_features.html#a6e6d4502fb8c5e41dea6ac32116050faae2bdb81415edb3da2ad99e152a98ddfc',1,'wxComboCtrlFeatures']]],
+  ['textindent',['TextIndent',['../structwx_combo_ctrl_features.html#a58a86088b84a95c19601d3a89d7360b2ae2bdb81415edb3da2ad99e152a98ddfc',1,'wxComboCtrlFeatures']]],
   ['textwidth',['TextWidth',['../classwx_styled_text_ctrl.html#a52586525a7af5c901828ca8a44ae71ba',1,'wxStyledTextCtrl']]],
   ['textwrapper_2eh',['textwrapper.h',['../textwrapper_8h.html',1,'']]],
   ['tglbtn_2eh',['tglbtn.h',['../tglbtn_8h.html',1,'']]],
@@ -40,7 +40,7 @@ var searchData=
   ['thread_2eh',['thread.h',['../interface_2wx_2thread_8h.html',1,'']]],
   ['threadid',['threadId',['../classwx_log_record_info.html#af7766219720d7215dcdef349d247916e',1,'wxLogRecordInfo']]],
   ['thu',['Thu',['../classwx_date_time.html#a9ce844e5c79b28711f52ae2d9a571457aefdce3348770a8e30443bd559cd272e9',1,'wxDateTime']]],
-  ['tile',['Tile',['../classwx_aui_m_d_i_parent_frame.html#a125a453a98704396877f8fa62a551b5b',1,'wxAuiMDIParentFrame::Tile()'],['../classwx_m_d_i_parent_frame.html#a7f1eff1bf46b4f7a399d1d20ca3ed374',1,'wxMDIParentFrame::Tile()']]],
+  ['tile',['Tile',['../classwx_m_d_i_parent_frame.html#a7f1eff1bf46b4f7a399d1d20ca3ed374',1,'wxMDIParentFrame']]],
   ['time',['Time',['../classwx_stop_watch.html#aa80ff19ed90b2b99c879ec9ea3e7a71d',1,'wxStopWatch']]],
   ['time_2eh',['time.h',['../time_8h.html',1,'']]],
   ['timectrl_2eh',['timectrl.h',['../timectrl_8h.html',1,'']]],
@@ -54,22 +54,25 @@ var searchData=
   ['tipdlg_2eh',['tipdlg.h',['../tipdlg_8h.html',1,'']]],
   ['tips_2eh',['tips.h',['../tips_8h.html',1,'']]],
   ['tipwin_2eh',['tipwin.h',['../tipwin_8h.html',1,'']]],
+  ['title',['Title',['../classwx_busy_info_flags.html#aa514f1204a0a3f43c6529360d495de22',1,'wxBusyInfoFlags']]],
   ['tls_2eh',['tls.h',['../tls_8h.html',1,'']]],
   ['tm',['Tm',['../structwx_date_time_1_1_tm.html',1,'wxDateTime']]],
   ['to8bitdata',['To8BitData',['../classwx_string.html#afa91a632574bcbba1bf35b54f2c5562a',1,'wxString']]],
-  ['toascii',['ToAscii',['../classwx_string.html#a2fec30dc8959d4fd3a56cd148bf1e57a',1,'wxString::ToAscii() const '],['../classwx_string.html#a9c39f3ca6c54a28347527c28e7c18f23',1,'wxString::ToAscii() const ']]],
+  ['toascii',['ToAscii',['../classwx_string.html#a51d79ada5701a552d698c8fa9ffe208b',1,'wxString::ToAscii(char replaceWith= &apos;_&apos;) const '],['../classwx_string.html#acd171199184fea05c454ebfd309d6e68',1,'wxString::ToAscii(char replaceWith= &apos;_&apos;) const ']]],
   ['tocdouble',['ToCDouble',['../classwx_string.html#a81ee01c0c1f9c2264506d674f1f2b733',1,'wxString']]],
   ['toclong',['ToCLong',['../classwx_string.html#a2d7fb808fae67a4226ebeedf854a5a03',1,'wxString']]],
   ['toculong',['ToCULong',['../classwx_string.html#a545b481942916202dacaaee5e558d035',1,'wxString']]],
   ['today',['Today',['../classwx_date_time.html#af730202238b9acd5a5df2977fa40c569',1,'wxDateTime']]],
+  ['todip',['ToDIP',['../classwx_window.html#ae9b6cfa33d3250fea284d6257e09d123',1,'wxWindow::ToDIP(const wxSize &amp;sz) const '],['../classwx_window.html#a94cdc7e439ec0700e678656a003b4e8c',1,'wxWindow::ToDIP(const wxPoint &amp;pt) const '],['../classwx_window.html#af30ae727bcf8b445a580979d738d421e',1,'wxWindow::ToDIP(int d) const '],['../classwx_window.html#a664dc49139d0f91fc3717994b0a5b4e6',1,'wxWindow::ToDIP(const wxSize &amp;sz, const wxWindow *w)'],['../classwx_window.html#aef413f1d0252a7a5a29512e8ab5e7c91',1,'wxWindow::ToDIP(const wxPoint &amp;pt, const wxWindow *w)'],['../classwx_window.html#a664dc49139d0f91fc3717994b0a5b4e6',1,'wxWindow::ToDIP(const wxSize &amp;sz, const wxWindow *w)']]],
   ['todo_20list',['Todo List',['../todo.html',1,'']]],
   ['todouble',['ToDouble',['../classwx_long_long.html#a5d0d84321018245413ac71939f3d80d2',1,'wxLongLong::ToDouble()'],['../classwx_string.html#afca98ce954f669ec69696372e81d46ac',1,'wxString::ToDouble()']]],
-  ['toggle',['Toggle',['../classwx_tool_bar_tool_base.html#ac55ffb6ad5680a65221d3ccbbb1271f9',1,'wxToolBarToolBase::Toggle(bool toggle)'],['../classwx_tool_bar_tool_base.html#ad1cd74a3720137b0db632164bb046ddc',1,'wxToolBarToolBase::Toggle()'],['../classwx_tree_ctrl.html#a618a620d9a434bacf91a51202ab807b1',1,'wxTreeCtrl::Toggle()'],['../classwx_v_list_box.html#ae530f18573bd96ea497d64b1b1b18905',1,'wxVListBox::Toggle()']]],
+  ['toggle',['Toggle',['../classwx_tree_ctrl.html#a618a620d9a434bacf91a51202ab807b1',1,'wxTreeCtrl::Toggle()'],['../classwx_v_list_box.html#ae530f18573bd96ea497d64b1b1b18905',1,'wxVListBox::Toggle()']]],
   ['togglebutton',['ToggleButton',['../classwx_ribbon_button_bar.html#a8d69e9a70bf38693cc349bbf76f0735a',1,'wxRibbonButtonBar']]],
   ['togglecaretsticky',['ToggleCaretSticky',['../classwx_styled_text_ctrl.html#adfc2b57b5e8d2f1fb512437344aab923',1,'wxStyledTextCtrl']]],
   ['toggleflag',['ToggleFlag',['../classwx_settable_header_column.html#a4734d269e6b4454aae75eb3641f4b023',1,'wxSettableHeaderColumn']]],
   ['togglefold',['ToggleFold',['../classwx_styled_text_ctrl.html#a41820dbb85f0b04756552982f276e621',1,'wxStyledTextCtrl']]],
   ['toggleitemselection',['ToggleItemSelection',['../classwx_tree_ctrl.html#a458eab144e16efbaf283748bacc475f7',1,'wxTreeCtrl']]],
+  ['togglesortbycolumn',['ToggleSortByColumn',['../classwx_data_view_ctrl.html#a84b66d5faa59df90591417d3b4a520f8',1,'wxDataViewCtrl']]],
   ['togglesortorder',['ToggleSortOrder',['../classwx_settable_header_column.html#a85f9c3278526a0f60b79fd32607d31bb',1,'wxSettableHeaderColumn']]],
   ['toggletool',['ToggleTool',['../classwx_aui_tool_bar.html#af817c944bfe3e437e5fbac112aa9ac9c',1,'wxAuiToolBar::ToggleTool()'],['../classwx_ribbon_tool_bar.html#aaaf93abfe569a7c42a240d804e750131',1,'wxRibbonToolBar::ToggleTool()'],['../classwx_tool_bar.html#a9a7a9fb115b35f267d4b10a293667542',1,'wxToolBar::ToggleTool()']]],
   ['togglewindowstyle',['ToggleWindowStyle',['../classwx_window.html#a8a4fa47129de552bfec37db8c69688a2',1,'wxWindow']]],
@@ -77,15 +80,13 @@ var searchData=
   ['tokenzr_2eh',['tokenzr.h',['../tokenzr_8h.html',1,'']]],
   ['tolong',['ToLong',['../classwx_long_long.html#a1f3e078524d8d495bbc130c93b6fbdf2',1,'wxLongLong::ToLong()'],['../classwx_string.html#abb54083175bbc1e1164616b4aa64fcd8',1,'wxString::ToLong()']]],
   ['tolonglong',['ToLongLong',['../classwx_string.html#a978e566d90ff4ed900fb353c7160c4d2',1,'wxString']]],
-  ['toolbar',['toolbar',['../classwx_aui_dock_info.html#aa3099d3d1c138e83b9749e70998743c5',1,'wxAuiDockInfo']]],
-  ['toolbar_2eh',['toolbar.h',['../interface_2wx_2ribbon_2toolbar_8h.html',1,'']]],
   ['toolbar_2eh',['toolbar.h',['../docs_2doxygen_2overviews_2toolbar_8h.html',1,'']]],
+  ['toolbar_2eh',['toolbar.h',['../interface_2wx_2ribbon_2toolbar_8h.html',1,'']]],
   ['toolbar_2eh',['toolbar.h',['../interface_2wx_2toolbar_8h.html',1,'']]],
   ['toolbarpane',['ToolbarPane',['../classwx_aui_pane_info.html#a6ef47a9e70b74a1b9b0260f009ecf3c5',1,'wxAuiPaneInfo']]],
   ['toolbook_2eh',['toolbook.h',['../toolbook_8h.html',1,'']]],
-  ['tooltip',['tooltip',['../classwx_aui_notebook_page.html#a9822b94cdd505192dc9c35a8d10c14fd',1,'wxAuiNotebookPage']]],
   ['tooltip_2eh',['tooltip.h',['../tooltip_8h.html',1,'']]],
-  ['top',['top',['../classwx_layout_constraints.html#a129cfa4472889328c561b3c7dfa6494b',1,'wxLayoutConstraints::top()'],['../classwx_stack_3_01_t_01_4.html#a88468b033c07c9e1e6db68f10d405d37',1,'wxStack&lt; T &gt;::top()'],['../classwx_stack_3_01_t_01_4.html#a7f05c401d1a331de4ce3a50c65d01404',1,'wxStack&lt; T &gt;::top()'],['../classwx_aui_pane_info.html#a2b6d3cdd44942939cf0cb456307d4e4f',1,'wxAuiPaneInfo::Top()'],['../classwx_sizer_flags.html#a332570b2ce022f6ad56206eda0b866ae',1,'wxSizerFlags::Top()']]],
+  ['top',['Top',['../classwx_aui_pane_info.html#a2b6d3cdd44942939cf0cb456307d4e4f',1,'wxAuiPaneInfo::Top()'],['../classwx_sizer_flags.html#a332570b2ce022f6ad56206eda0b866ae',1,'wxSizerFlags::Top()'],['../classwx_layout_constraints.html#a129cfa4472889328c561b3c7dfa6494b',1,'wxLayoutConstraints::top()'],['../classwx_stack_3_01_t_01_4.html#a88468b033c07c9e1e6db68f10d405d37',1,'wxStack&lt; T &gt;::top()'],['../classwx_stack_3_01_t_01_4.html#a7f05c401d1a331de4ce3a50c65d01404',1,'wxStack&lt; T &gt;::top()']]],
   ['topdockable',['TopDockable',['../classwx_aui_pane_info.html#a1485700166fccf0d5e26795e836a35f9',1,'wxAuiPaneInfo']]],
   ['topics_2eh',['topics.h',['../topics_8h.html',1,'']]],
   ['toplevel_2eh',['toplevel.h',['../persist_2toplevel_8h.html',1,'']]],
@@ -113,15 +114,15 @@ var searchData=
   ['transformdistance',['TransformDistance',['../classwx_affine_matrix2_d.html#a47def85a019c68e7b672c34b3e2b8427',1,'wxAffineMatrix2D::TransformDistance(const wxPoint2DDouble &amp;p) const '],['../classwx_affine_matrix2_d.html#ab024db742b913618e7138b846656c385',1,'wxAffineMatrix2D::TransformDistance(wxDouble *dx, wxDouble *dy) const '],['../classwx_affine_matrix2_d_base.html#a6503debd3b857e360d53a375bc7e8429',1,'wxAffineMatrix2DBase::TransformDistance(const wxPoint2DDouble &amp;p) const '],['../classwx_affine_matrix2_d_base.html#a1bd444b69b9f13469793924b66df3bd4',1,'wxAffineMatrix2DBase::TransformDistance(wxDouble *dx, wxDouble *dy) const '],['../classwx_graphics_matrix.html#a7c260921b498791c1355d3ae2fe4a3e0',1,'wxGraphicsMatrix::TransformDistance()']]],
   ['transformpoint',['TransformPoint',['../classwx_affine_matrix2_d.html#aad371443939e426e693a05befe2e3cd3',1,'wxAffineMatrix2D::TransformPoint(const wxPoint2DDouble &amp;p) const '],['../classwx_affine_matrix2_d.html#ac2fe105565117945524e1305152647e1',1,'wxAffineMatrix2D::TransformPoint(wxDouble *x, wxDouble *y) const '],['../classwx_affine_matrix2_d_base.html#a00b4abff8fe77431fc4ed2a9523660c9',1,'wxAffineMatrix2DBase::TransformPoint(const wxPoint2DDouble &amp;p) const '],['../classwx_affine_matrix2_d_base.html#ace16a72f1378d410936002f40c0a4841',1,'wxAffineMatrix2DBase::TransformPoint(wxDouble *x, wxDouble *y) const '],['../classwx_graphics_matrix.html#a27f4264be5407a9a584297c822b8deae',1,'wxGraphicsMatrix::TransformPoint()']]],
   ['translate',['Translate',['../classwx_affine_matrix2_d.html#a08f03e2a7b5ce37e6dc60d91ba2c43ab',1,'wxAffineMatrix2D::Translate()'],['../classwx_affine_matrix2_d_base.html#a5a2ab636aeff6db99cb3b534b0d9ea3a',1,'wxAffineMatrix2DBase::Translate()'],['../classwx_graphics_context.html#a3fcc8a79248f192c637ff89466939916',1,'wxGraphicsContext::Translate()'],['../classwx_graphics_matrix.html#ae91dc96cb34b4562179efb6c9857dc75',1,'wxGraphicsMatrix::Translate()']]],
-  ['translateval',['TranslateVal',['../classwx_system_colour_property.html#a8dd91ba1abdf8c89bd436abf4eb5772c',1,'wxSystemColourProperty::TranslateVal(wxColourPropertyValue &amp;v) const '],['../classwx_system_colour_property.html#a3ed30f919ad6cceaad91447c1c67044d',1,'wxSystemColourProperty::TranslateVal(int type, const wxColour &amp;colour) const ']]],
   ['translation_2eh',['translation.h',['../translation_8h.html',1,'']]],
   ['translations_2eh',['translations.h',['../translations_8h.html',1,'']]],
+  ['transparency',['Transparency',['../classwx_busy_info_flags.html#a6fddc2b30145b6f989e5b9e69dfdc557',1,'wxBusyInfoFlags']]],
   ['traverse',['Traverse',['../classwx_dir.html#a7621f55a0dff2a394e6da1a61e427df1',1,'wxDir']]],
   ['treebase_2eh',['treebase.h',['../treebase_8h.html',1,'']]],
-  ['treebook_2eh',['treebook.h',['../persist_2treebook_8h.html',1,'']]],
   ['treebook_2eh',['treebook.h',['../treebook_8h.html',1,'']]],
-  ['treectrl_2eh',['treectrl.h',['../docs_2doxygen_2overviews_2treectrl_8h.html',1,'']]],
+  ['treebook_2eh',['treebook.h',['../persist_2treebook_8h.html',1,'']]],
   ['treectrl_2eh',['treectrl.h',['../interface_2wx_2treectrl_8h.html',1,'']]],
+  ['treectrl_2eh',['treectrl.h',['../docs_2doxygen_2overviews_2treectrl_8h.html',1,'']]],
   ['treelist_2eh',['treelist.h',['../treelist_8h.html',1,'']]],
   ['trim',['Trim',['../classwx_string.html#aefd36feb8f3c36edcf3322f84de0bfc4',1,'wxString']]],
   ['tripleborder',['TripleBorder',['../classwx_sizer_flags.html#a799590935571940a5a7c28c75a324243',1,'wxSizerFlags']]],
@@ -133,7 +134,7 @@ var searchData=
   ['trywait',['TryWait',['../classwx_semaphore.html#a578840a5c04cea87b0121c8e43d480a2',1,'wxSemaphore']]],
   ['tue',['Tue',['../classwx_date_time.html#a9ce844e5c79b28711f52ae2d9a571457ae1277871c9d23518b6137b9d9b005138',1,'wxDateTime']]],
   ['txtstrm_2eh',['txtstrm.h',['../txtstrm_8h.html',1,'']]],
-  ['type',['type',['../classwx_aui_dock_u_i_part.html#a5cdc8cbf181b3920e2fd7a5265252c96',1,'wxAuiDockUIPart::type()'],['../structwx_cmd_line_entry_desc.html#ab37bbf61b24d4cbea96f42cac315f0ea',1,'wxCmdLineEntryDesc::type()']]],
+  ['type',['type',['../structwx_cmd_line_entry_desc.html#ab37bbf61b24d4cbea96f42cac315f0ea',1,'wxCmdLineEntryDesc']]],
   ['type_5fbinary',['Type_Binary',['../classwx_reg_key.html#a50c331bab4eb972c283eeaf59fc448aea74fb86bd34628fe6c23cfaa7b547b79a',1,'wxRegKey']]],
   ['type_5fboolean',['Type_Boolean',['../classwx_config_base.html#a499282208b4b9e90cbfe60de25745bc4a5338e90a8c51020109928f3177c06caf',1,'wxConfigBase']]],
   ['type_5fdword',['Type_Dword',['../classwx_reg_key.html#a50c331bab4eb972c283eeaf59fc448aeacb0782c3f7b99336f78371753970cf6f',1,'wxRegKey']]],
@@ -150,15 +151,6 @@ var searchData=
   ['type_5fresource_5frequirements_5flist',['Type_Resource_requirements_list',['../classwx_reg_key.html#a50c331bab4eb972c283eeaf59fc448aea47a10b01b23342d005164295bb4a8935',1,'wxRegKey']]],
   ['type_5fstring',['Type_String',['../classwx_config_base.html#a499282208b4b9e90cbfe60de25745bc4afeb4cd8ae582520fd2d45ec35b316d0a',1,'wxConfigBase::Type_String()'],['../classwx_reg_key.html#a50c331bab4eb972c283eeaf59fc448aea71e34e7ea0dd2326613f48db8d086c16',1,'wxRegKey::Type_String()']]],
   ['type_5funknown',['Type_Unknown',['../classwx_config_base.html#a499282208b4b9e90cbfe60de25745bc4a186e69ade61db5ba7e5fc2366d2388fc',1,'wxConfigBase']]],
-  ['typebackground',['typeBackground',['../classwx_aui_dock_u_i_part.html#aa48c91639c74d80c5afc3bc25959511ca4bdc349d92418ccbc898bcfeee7e6f98',1,'wxAuiDockUIPart']]],
-  ['typecaption',['typeCaption',['../classwx_aui_dock_u_i_part.html#aa48c91639c74d80c5afc3bc25959511ca001d265d11402b740f01034606edf50f',1,'wxAuiDockUIPart']]],
   ['typedefault',['typeDefault',['../classwx_text_file.html#a2556d86c0c6130379d9122a3c076340b',1,'wxTextFile']]],
-  ['typedock',['typeDock',['../classwx_aui_dock_u_i_part.html#aa48c91639c74d80c5afc3bc25959511caa06d723eac020e7d3a6c0f251c052159',1,'wxAuiDockUIPart']]],
-  ['typedocksizer',['typeDockSizer',['../classwx_aui_dock_u_i_part.html#aa48c91639c74d80c5afc3bc25959511caa9fcd7c3db3b59a2923361a5488d6cd2',1,'wxAuiDockUIPart']]],
-  ['typegripper',['typeGripper',['../classwx_aui_dock_u_i_part.html#aa48c91639c74d80c5afc3bc25959511ca76088497e11323eb6936c7cbbe81c809',1,'wxAuiDockUIPart']]],
-  ['typepane',['typePane',['../classwx_aui_dock_u_i_part.html#aa48c91639c74d80c5afc3bc25959511cac4fa0fb93c39ef29cab46f3f52ea27f4',1,'wxAuiDockUIPart']]],
-  ['typepaneborder',['typePaneBorder',['../classwx_aui_dock_u_i_part.html#aa48c91639c74d80c5afc3bc25959511ca5a72a179923564489ab1ffe75be26613',1,'wxAuiDockUIPart']]],
-  ['typepanebutton',['typePaneButton',['../classwx_aui_dock_u_i_part.html#aa48c91639c74d80c5afc3bc25959511ca34d9ef2741b026869c05c2b275a47621',1,'wxAuiDockUIPart']]],
-  ['typepanesizer',['typePaneSizer',['../classwx_aui_dock_u_i_part.html#aa48c91639c74d80c5afc3bc25959511ca70810637146ca47d021179823ee18b93',1,'wxAuiDockUIPart']]],
   ['tz',['TZ',['../classwx_date_time.html#a4db12283a6c06cea4c92528fbb7f88bb',1,'wxDateTime']]]
 ];
