@@ -16,7 +16,6 @@ var searchData=
   ['wxauibuttonid',['wxAuiButtonId',['../dockart_8h.html#a69100375d2c563a9b848f6dd9292bff6',1,'dockart.h']]],
   ['wxauimanagerdock',['wxAuiManagerDock',['../framemanager_8h.html#a80ff0066837866cf13560dd1127cbb16',1,'framemanager.h']]],
   ['wxauimanageroption',['wxAuiManagerOption',['../framemanager_8h.html#a79f21eb4f287efb5bc66e4a04deedf89',1,'framemanager.h']]],
-  ['wxauinotebookoption',['wxAuiNotebookOption',['../auibook_8h.html#a4cbe749dd7778062eeca81d6b1e57195',1,'auibook.h']]],
   ['wxauipanebuttonstate',['wxAuiPaneButtonState',['../dockart_8h.html#a6ce0fe49238f90e0c430e5456ea8d852',1,'dockart.h']]],
   ['wxauipanedockartgradients',['wxAuiPaneDockArtGradients',['../dockart_8h.html#a615f7ec3429260746a2dd465a14fb1ae',1,'dockart.h']]],
   ['wxauipanedockartsetting',['wxAuiPaneDockArtSetting',['../group__group__class__aui.html#gab09190c5a3f9cd3628819fbe93a9caa0',1,'dockart.h']]],
@@ -54,8 +53,8 @@ var searchData=
   ['wxduplexmode',['wxDuplexMode',['../defs_8h.html#a0f2596c210e8f39fb074cd2fb312ccf2',1,'defs.h']]],
   ['wxdynamiclibrarycategory',['wxDynamicLibraryCategory',['../dynlib_8h.html#a71fa4e7e0f6f4b39883faf98c5120dab',1,'dynlib.h']]],
   ['wxedge',['wxEdge',['../layout_8h.html#add86e0d78c35fcb5c14d99b9732c58b7',1,'layout.h']]],
-  ['wxellipsizeflags',['wxEllipsizeFlags',['../control_8h.html#ad7c89373a31bffb2388cfa2b98abea39',1,'control.h']]],
-  ['wxellipsizemode',['wxEllipsizeMode',['../control_8h.html#a0293befa07fe89f6efd8caec89c3b489',1,'control.h']]],
+  ['wxellipsizeflags',['wxEllipsizeFlags',['../gdicmn_8h.html#ad7c89373a31bffb2388cfa2b98abea39',1,'gdicmn.h']]],
+  ['wxellipsizemode',['wxEllipsizeMode',['../gdicmn_8h.html#a0293befa07fe89f6efd8caec89c3b489',1,'gdicmn.h']]],
   ['wxendianness',['wxEndianness',['../platinfo_8h.html#a604702957b3c219643e1c989766f7047',1,'platinfo.h']]],
   ['wxeol',['wxEOL',['../txtstrm_8h.html#a4b64b170cc32ba60ccef13c2a64fec70',1,'txtstrm.h']]],
   ['wxeventcategory',['wxEventCategory',['../event_8h.html#a685cc8dc6176be3ab0d40e3f72719e7d',1,'event.h']]],
@@ -79,7 +78,6 @@ var searchData=
   ['wxfswwarningtype',['wxFSWWarningType',['../fswatcher_8h.html#a1a9b4dfd8ebb0613675fc64af52b81d9',1,'fswatcher.h']]],
   ['wxgeometrycentre',['wxGeometryCentre',['../defs_8h.html#ae160ea382a8f7921484db9d499516daf',1,'defs.h']]],
   ['wxgridcellfloatformat',['wxGridCellFloatFormat',['../interface_2wx_2grid_8h.html#a6594fb49b365ff74b4f51d0a024d1105',1,'grid.h']]],
-  ['wxgriddirection',['wxGridDirection',['../interface_2wx_2grid_8h.html#a217feca5b3c92d0b1870dcddd719716a',1,'grid.h']]],
   ['wxgridrenderstyle',['wxGridRenderStyle',['../interface_2wx_2grid_8h.html#a6c6e4c1a30cf97ac7d4f1a96ab2a9fac',1,'grid.h']]],
   ['wxgridselectionmodes',['wxGridSelectionModes',['../classwx_grid.html#a567e86cd28859368c01321d5f67e08d6',1,'wxGrid']]],
   ['wxgridtablerequest',['wxGridTableRequest',['../interface_2wx_2grid_8h.html#ab169f7bee913c59d3ab0ee160c871263',1,'grid.h']]],
@@ -109,7 +107,6 @@ var searchData=
   ['wxlistcolumnformat',['wxListColumnFormat',['../interface_2wx_2listctrl_8h.html#afddccbb0d7cf18f9b205f00efc5738d0',1,'listctrl.h']]],
   ['wxlocalecategory',['wxLocaleCategory',['../intl_8h.html#a934e5f080f46c8c1b3c043775466f121',1,'intl.h']]],
   ['wxlocaleinfo',['wxLocaleInfo',['../intl_8h.html#a54d3421c44d428cc5cce0c772d583c34',1,'intl.h']]],
-  ['wxlocaleinitflags',['wxLocaleInitFlags',['../intl_8h.html#afb64604cab524627489a96f6826055df',1,'intl.h']]],
   ['wxloglevelvalues',['wxLogLevelValues',['../interface_2wx_2log_8h.html#aacf1e0ade132ca66e9414ee658c94887',1,'log.h']]],
   ['wxmappingmode',['wxMappingMode',['../interface_2wx_2dc_8h.html#a5a641b839b9ac2ff94514d0596f6e20a',1,'dc.h']]],
   ['wxmediactrlplayercontrols',['wxMediaCtrlPlayerControls',['../mediactrl_8h.html#a5a30300b432bd386c9b9bf04106e847d',1,'mediactrl.h']]],
@@ -135,19 +132,16 @@ var searchData=
   ['wxpenjoin',['wxPenJoin',['../pen_8h.html#a2f214bacb569721da370aab5dbc2a9f4',1,'pen.h']]],
   ['wxpenstyle',['wxPenStyle',['../pen_8h.html#aebe64277219894a55d6b963607ad5f54',1,'pen.h']]],
   ['wxpg_5fex_5fwindow_5fstyles',['wxPG_EX_WINDOW_STYLES',['../interface_2wx_2propgrid_2propgrid_8h.html#aeebee6f1621b080999ea22a5b76b00a6',1,'propgrid.h']]],
-  ['wxpg_5fgetpropertyvalues_5fflags',['wxPG_GETPROPERTYVALUES_FLAGS',['../propgriddefs_8h.html#a77bb7880e3ea2359f13566eff2a1478c',1,'propgriddefs.h']]],
   ['wxpg_5fiterator_5fflags',['wxPG_ITERATOR_FLAGS',['../propgridpagestate_8h.html#a307ba26bf1eeb9d76108893f4f723b0a',1,'propgridpagestate.h']]],
   ['wxpg_5fkeyboard_5factions',['wxPG_KEYBOARD_ACTIONS',['../interface_2wx_2propgrid_2propgrid_8h.html#a241dc2408e56a31edee6739e9b101b0a',1,'propgrid.h']]],
-  ['wxpg_5fmisc_5farg_5fflags',['wxPG_MISC_ARG_FLAGS',['../propgriddefs_8h.html#a2e574c079c342fab1960477005472503',1,'propgriddefs.h']]],
-  ['wxpg_5fsetvalue_5fflags',['wxPG_SETVALUE_FLAGS',['../propgriddefs_8h.html#ac3b998155d4217dca44e0396ba06d6f0',1,'propgriddefs.h']]],
   ['wxpg_5fvalidation_5ffailure_5fbehavior_5fflags',['wxPG_VALIDATION_FAILURE_BEHAVIOR_FLAGS',['../interface_2wx_2propgrid_2propgrid_8h.html#a509a11f37ea5e56864e257cde913035e',1,'propgrid.h']]],
   ['wxpg_5fwindow_5fstyles',['wxPG_WINDOW_STYLES',['../interface_2wx_2propgrid_2propgrid_8h.html#a967b646b15085e115051d83a65ffdfe8',1,'propgrid.h']]],
-  ['wxpgnumericvalidationconstants',['wxPGNumericValidationConstants',['../props_8h.html#a8ee9000aed16e1360477a5f821b0c992',1,'props.h']]],
   ['wxpgpropertyflags',['wxPGPropertyFlags',['../property_8h.html#a2aac85b6d4e1018849f0026b62f1b751',1,'property.h']]],
   ['wxplugincategory',['wxPluginCategory',['../dynlib_8h.html#a0e1300907aa8d5dedef66ee5fc192eaa',1,'dynlib.h']]],
   ['wxpolygonfillmode',['wxPolygonFillMode',['../gdicmn_8h.html#a771e5c5703eb406b19fb50bb718eee05',1,'gdicmn.h']]],
   ['wxportid',['wxPortId',['../platinfo_8h.html#a4acbc14b366d6ce2875f809be384757b',1,'platinfo.h']]],
   ['wxposixpermissions',['wxPosixPermissions',['../group__group__funcmacro__file.html#ga64460401fb35c137c9df28f3c019694d',1,'filefn.h']]],
+  ['wxpowerresourcekind',['wxPowerResourceKind',['../power_8h.html#a85435183edc96b79a76ceefb6b7d0815',1,'power.h']]],
   ['wxpowertype',['wxPowerType',['../power_8h.html#ae3f5c432e430cf701d4cef6abf893632',1,'power.h']]],
   ['wxpreviewframemodalitykind',['wxPreviewFrameModalityKind',['../print_8h.html#ad5bb1e32993261f9f12793c3050bb15f',1,'print.h']]],
   ['wxprintbin',['wxPrintBin',['../cmndata_8h.html#ac5a8648f833a003ac36596a82e8361b9',1,'cmndata.h']]],
@@ -160,12 +154,10 @@ var searchData=
   ['wxregioncontain',['wxRegionContain',['../region_8h.html#aa3ced1100e2b9a034e102e5938664cca',1,'region.h']]],
   ['wxrelationship',['wxRelationship',['../layout_8h.html#a9f3a78fa78c99c527b87047207a7b3a1',1,'layout.h']]],
   ['wxribbonartsetting',['wxRibbonArtSetting',['../art_8h.html#a1d09d963ecc6e5a290768e15a1f70155',1,'art.h']]],
-  ['wxribbonbaroption',['wxRibbonBarOption',['../bar_8h.html#a063dd5f6988f60473a69b458e0825c0c',1,'bar.h']]],
   ['wxribbonbuttonbarbuttonstate',['wxRibbonButtonBarButtonState',['../buttonbar_8h.html#abcc37993f6b41cbfd92091c612368eda',1,'buttonbar.h']]],
   ['wxribbonbuttonkind',['wxRibbonButtonKind',['../art_8h.html#a49672bfa76086982645f3797b0162e19',1,'art.h']]],
   ['wxribbondisplaymode',['wxRibbonDisplayMode',['../bar_8h.html#aae4363bcdf07ea1b5cb5b9c29e0d60a6',1,'bar.h']]],
   ['wxribbongallerybuttonstate',['wxRibbonGalleryButtonState',['../gallery_8h.html#a5f74710c9dd8307b9f67ff4972c9c5c0',1,'gallery.h']]],
-  ['wxribbonpaneloption',['wxRibbonPanelOption',['../ribbon_2panel_8h.html#a075ddd0d7e78829214cbf87665deffe7',1,'panel.h']]],
   ['wxribbonscrollbuttonstyle',['wxRibbonScrollButtonStyle',['../art_8h.html#af1a48dec08a6e9f2501acbf98d545ab1',1,'art.h']]],
   ['wxrichtextcommandid',['wxRichTextCommandId',['../richtextbuffer_8h.html#abfe80b5388eddd51c35f2c318cf33a80',1,'richtextbuffer.h']]],
   ['wxrichtextctrlselectionstate',['wxRichTextCtrlSelectionState',['../interface_2wx_2richtext_2richtextctrl_8h.html#a38ca0203735b66a27ae13e7d7986b393',1,'richtextctrl.h']]],
@@ -201,7 +193,9 @@ var searchData=
   ['wxsystemscreentype',['wxSystemScreenType',['../settings_8h.html#a805b469950075040f8fc4925d6507419',1,'settings.h']]],
   ['wxtarformat',['wxTarFormat',['../tarstrm_8h.html#afdc9a1d1de204d191ef3b8f6f786134d',1,'tarstrm.h']]],
   ['wxtartype',['wxTarType',['../tarstrm_8h.html#a182207a2794a58c1c0c21ea6c8ed865f',1,'tarstrm.h']]],
+  ['wxtaskbarbuttonstate',['wxTaskBarButtonState',['../taskbarbutton_8h.html#a6ca6503c3f6b99285c8449951b520bbf',1,'taskbarbutton.h']]],
   ['wxtaskbaricontype',['wxTaskBarIconType',['../taskbar_8h.html#a51fd8660b8ae3cd5773bc21a02883db2',1,'taskbar.h']]],
+  ['wxtaskbarjumplistitemtype',['wxTaskBarJumpListItemType',['../taskbarbutton_8h.html#aa7dfda164be872d16d8918e5e540e777',1,'taskbarbutton.h']]],
   ['wxtextattralignment',['wxTextAttrAlignment',['../textctrl_8h.html#acf93ad4eb51199602dc2af60ca78b4e5',1,'textctrl.h']]],
   ['wxtextattrborderflags',['wxTextAttrBorderFlags',['../richtextbuffer_8h.html#a80c55e720e852cd7d830f05742d81ba8',1,'richtextbuffer.h']]],
   ['wxtextattrborderstyle',['wxTextAttrBorderStyle',['../richtextbuffer_8h.html#adab4f4f5653fab50791a0b67ccfaf265',1,'richtextbuffer.h']]],
@@ -218,6 +212,7 @@ var searchData=
   ['wxtextboxattrfloatstyle',['wxTextBoxAttrFloatStyle',['../richtextbuffer_8h.html#a116ee323e2700a60bc2b603001958526',1,'richtextbuffer.h']]],
   ['wxtextboxattrposition',['wxTextBoxAttrPosition',['../richtextbuffer_8h.html#a43150851c928dea903e8856cd646c3e9',1,'richtextbuffer.h']]],
   ['wxtextboxattrverticalalignment',['wxTextBoxAttrVerticalAlignment',['../richtextbuffer_8h.html#adde8b611f7482b2915ae143b9658a5f1',1,'richtextbuffer.h']]],
+  ['wxtextboxattrwhitespacemode',['wxTextBoxAttrWhitespaceMode',['../richtextbuffer_8h.html#aa57988b46df64e39929b2bf0d7b694a0',1,'richtextbuffer.h']]],
   ['wxtextctrlhittestresult',['wxTextCtrlHitTestResult',['../textctrl_8h.html#a0ca70276b66011b1ca0a120b8c20fd16',1,'textctrl.h']]],
   ['wxtextfiletype',['wxTextFileType',['../textfile_8h.html#a6a6d37c2bb834f5ffba195db0eb6e023',1,'textfile.h']]],
   ['wxtextvalidatorstyle',['wxTextValidatorStyle',['../valtext_8h.html#aa02d29254d60e0c81f17696c9cecbd07',1,'valtext.h']]],
