@@ -1,17 +1,16 @@
 var searchData=
 [
-  ['macfinddefaulttypeandcreator',['MacFindDefaultTypeAndCreator',['../classwx_file_name.html#a2c3332f78de54e959fbca3591fb3f0f7',1,'wxFileName']]],
   ['macgetcommonmenubar',['MacGetCommonMenuBar',['../classwx_menu_bar.html#ab64676b036f37ff43df842b0dfffa39e',1,'wxMenuBar']]],
   ['macnewfile',['MacNewFile',['../classwx_app.html#adfccb56471d139a0bb29e96c3c6d12fa',1,'wxApp']]],
   ['macopenfile',['MacOpenFile',['../classwx_app.html#a420a1cef557cfe2edaee6ffdaaa5f7fb',1,'wxApp']]],
   ['macopenfiles',['MacOpenFiles',['../classwx_app.html#a0cf8d83fc9e1a7b7f911f29f05127d24',1,'wxApp']]],
   ['macopenurl',['MacOpenURL',['../classwx_app.html#a2c0ab6480ef6113488a5847a79044ac7',1,'wxApp']]],
   ['macprintfile',['MacPrintFile',['../classwx_app.html#a1f6e5bc7e119f4394fddae1782acd047',1,'wxApp']]],
-  ['macregisterdefaulttypeandcreator',['MacRegisterDefaultTypeAndCreator',['../classwx_file_name.html#a502d197ca3d2d018125e7734fa93edcb',1,'wxFileName']]],
   ['macreopenapp',['MacReopenApp',['../classwx_app.html#a2054c2fadff9170b91e474eb02c83227',1,'wxApp']]],
   ['macsetcommonmenubar',['MacSetCommonMenuBar',['../classwx_menu_bar.html#a1fd28115be9437d0dd7b1f99049ec905',1,'wxMenuBar']]],
-  ['macsetdefaulttypeandcreator',['MacSetDefaultTypeAndCreator',['../classwx_file_name.html#a7affe5717d2ad6f9036aadbdd21edf53',1,'wxFileName']]],
+  ['magnify',['Magnify',['../classwx_mouse_event.html#a4ff3ee248bd6b2cb39f6d6e543a71e24',1,'wxMouseEvent']]],
   ['mainloop',['MainLoop',['../classwx_app_console.html#a14523f3e9ab468c19c697c65484b36db',1,'wxAppConsole']]],
+  ['majorversion',['MajorVersion',['../classwx_g_l_context_attrs.html#a2855080de73bdd23cbbfbceddc35bbee',1,'wxGLContextAttrs']]],
   ['make',['Make',['../classwx_date_time_1_1_time_zone.html#a6bed142b6b0716f1100f8205e06db623',1,'wxDateTime::TimeZone::Make()'],['../classwx_dir.html#a97ee8e2dc2154b14bcd4b2f78cb5733d',1,'wxDir::Make()']]],
   ['makeabsolute',['MakeAbsolute',['../classwx_file_name.html#af947660cf109c3a39c4997f18a8670b6',1,'wxFileName']]],
   ['makebold',['MakeBold',['../classwx_font.html#a490c5c47ce9d42a9b430664c476e3940',1,'wxFont']]],
@@ -35,7 +34,6 @@ var searchData=
   ['makeobject',['MakeObject',['../classwx_rich_text_action.html#ae83b07dc6b3208d9e74a15491cecf2fe',1,'wxRichTextAction']]],
   ['makerelativeto',['MakeRelativeTo',['../classwx_file_name.html#ab7ac6ac2f4f0d7dca3fd9c9764ec818d',1,'wxFileName']]],
   ['makesmaller',['MakeSmaller',['../classwx_font.html#a119d3c74838fe89bc4f36ebd698421a2',1,'wxFont']]],
-  ['makestretchable',['MakeStretchable',['../classwx_tool_bar_tool_base.html#aa8d7cc442a447a96788bc91fbb892836',1,'wxToolBarToolBase']]],
   ['makestrikethrough',['MakeStrikethrough',['../classwx_font.html#a39b684e80dcc0e05e4aee6c3c1daa0a8',1,'wxFont']]],
   ['makestring',['MakeString',['../classwx_variant.html#ad6843bd4389d5140f40c39d0b12f35d9',1,'wxVariant']]],
   ['maketabvisible',['MakeTabVisible',['../classwx_aui_tab_container.html#ab530e4aebb04e570d20ebd3832ab3ae1',1,'wxAuiTabContainer']]],
@@ -79,18 +77,18 @@ var searchData=
   ['markersetforeground',['MarkerSetForeground',['../classwx_styled_text_ctrl.html#a7b038202798c153f2ba6c454dfa9f92b',1,'wxStyledTextCtrl']]],
   ['matches',['Matches',['../classwx_reg_ex.html#a4f63e65c83d19d7f4115e0cb46d797f2',1,'wxRegEx::Matches(const wxChar *text, int flags=0) const '],['../classwx_reg_ex.html#a761c31d59bc171d4c526e7d1da76ec9f',1,'wxRegEx::Matches(const wxChar *text, int flags, size_t len) const '],['../classwx_reg_ex.html#aac3f3acd35f8daf37ab2837473188e6a',1,'wxRegEx::Matches(const wxString &amp;text, int flags=0) const '],['../classwx_string.html#a0fef65e3bf7f77fa6858521f29a84e20',1,'wxString::Matches()'],['../structwx_video_mode.html#a5f9f9e2335cc8b87fadbb404fc2f47e0',1,'wxVideoMode::Matches()']]],
   ['max_5fsize',['max_size',['../classwx_list_3_01_t_01_4.html#aef1bb3d170c87215ff36443773a37017',1,'wxList&lt; T &gt;::max_size()'],['../classwx_string.html#a13471470cbc1443525bedef99e179baa',1,'wxString::max_size()']]],
-  ['maximize',['Maximize',['../classwx_aui_m_d_i_child_frame.html#abb72c6e0e37448f6854f589b90cbfffa',1,'wxAuiMDIChildFrame::Maximize()'],['../classwx_m_d_i_child_frame.html#a050f0818cb669338ad74b189b77e9b20',1,'wxMDIChildFrame::Maximize()'],['../classwx_top_level_window.html#addb1612e9f00ac82c2e19c2bac6ffc4f',1,'wxTopLevelWindow::Maximize()']]],
+  ['maximize',['Maximize',['../classwx_m_d_i_child_frame.html#a050f0818cb669338ad74b189b77e9b20',1,'wxMDIChildFrame::Maximize()'],['../classwx_top_level_window.html#addb1612e9f00ac82c2e19c2bac6ffc4f',1,'wxTopLevelWindow::Maximize()']]],
   ['maximizebutton',['MaximizeButton',['../classwx_aui_pane_info.html#a28842138907b56235c8f8ce3da77089b',1,'wxAuiPaneInfo']]],
   ['maxsize',['MaxSize',['../classwx_aui_pane_info.html#a9e2da447d00c6a7ce3a8440592a9b996',1,'wxAuiPaneInfo::MaxSize(const wxSize &amp;size)'],['../classwx_aui_pane_info.html#a68107e3967faae0260f49af227f55254',1,'wxAuiPaneInfo::MaxSize(int x, int y)']]],
   ['maxx',['MaxX',['../classwx_d_c.html#a8829696c6ebabed7053f8a9479fabeef',1,'wxDC']]],
   ['maxy',['MaxY',['../classwx_d_c.html#a90b1bc13bd01e442754e91935a8d0ef3',1,'wxDC']]],
   ['mb2wc',['MB2WC',['../classwx_m_b_conv.html#a79d63eff51836148157c986943835742',1,'wxMBConv']]],
   ['mb_5fstr',['mb_str',['../classwx_string.html#adcfd12e6d0765b1d74bccc3d63d02e98',1,'wxString']]],
+  ['measurebullet',['MeasureBullet',['../classwx_rich_text_renderer.html#a9f0c3be99190db7ec7dbe6e5bf11b58e',1,'wxRichTextRenderer::MeasureBullet()'],['../classwx_rich_text_std_renderer.html#a329113733f77c5c20d42fe8cf831845f',1,'wxRichTextStdRenderer::MeasureBullet()']]],
   ['member',['Member',['../classwx_list_3_01_t_01_4.html#a710612f09a76d234d949724405338e1d',1,'wxList&lt; T &gt;::Member()'],['../classwx_variant.html#ac28c74227400cd94366d081eaf4fc3dc',1,'wxVariant::Member()']]],
   ['merge',['Merge',['../classwx_rich_text_object.html#ad70ee3cfab55a5e48fb604f915871843',1,'wxRichTextObject::Merge()'],['../classwx_rich_text_plain_text.html#a34521d526e4897ae4bce16a478a8a342',1,'wxRichTextPlainText::Merge()'],['../classwx_text_attr.html#a591d90d4a675dcbdcd57bbef5557669b',1,'wxTextAttr::Merge(const wxTextAttr &amp;overlay)'],['../classwx_text_attr.html#ad51cefa334bbfa1bdcff33c05bf0c6ef',1,'wxTextAttr::Merge(const wxTextAttr &amp;base, const wxTextAttr &amp;overlay)']]],
   ['mergefrom',['MergeFrom',['../classwx_p_g_cell.html#aea2453886dc54ec6ac6144acf4d95597',1,'wxPGCell']]],
   ['mergeproperties',['MergeProperties',['../classwx_rich_text_properties.html#a65fc66fcdd2d8f2687ee8af98304284a',1,'wxRichTextProperties']]],
-  ['mergewith',['MergeWith',['../classwx_grid_cell_attr.html#ab22a6dbc9c6bc63b854969baddda57c6',1,'wxGridCellAttr']]],
   ['messageparameters',['MessageParameters',['../classwx_file_type_1_1_message_parameters.html#aacde350078c87df6853aa3949981a165',1,'wxFileType::MessageParameters::MessageParameters()'],['../classwx_file_type_1_1_message_parameters.html#a148911b186f3eab01ba3864a4383d826',1,'wxFileType::MessageParameters::MessageParameters(const wxString &amp;filename, const wxString &amp;mimetype=wxEmptyString)']]],
   ['metadown',['MetaDown',['../classwx_mouse_event.html#ac54b0063ff887f434fee23b5b1d4b518',1,'wxMouseEvent::MetaDown()'],['../classwx_grid_event.html#ad27099c2883b15e81863a432e7085186',1,'wxGridEvent::MetaDown()'],['../classwx_grid_size_event.html#a2d5feec68f9197cb89d011b0b5e5703e',1,'wxGridSizeEvent::MetaDown()'],['../classwx_grid_range_select_event.html#a8d872a1cee5110b0e4c900f656fcce4f',1,'wxGridRangeSelectEvent::MetaDown()'],['../classwx_keyboard_state.html#a8875366f7792d7fd5308cc240f5f0c5f',1,'wxKeyboardState::MetaDown()']]],
   ['mid',['Mid',['../classwx_string.html#a023d5f6b708eff5123f47498fcf151bc',1,'wxString']]],
@@ -100,7 +98,10 @@ var searchData=
   ['middleup',['MiddleUp',['../classwx_mouse_event.html#ac54542740e9bac83c4446846782d7733',1,'wxMouseEvent']]],
   ['millisecond',['Millisecond',['../classwx_time_span.html#a5b979776a9120071f0602e21a5be733f',1,'wxTimeSpan']]],
   ['milliseconds',['Milliseconds',['../classwx_time_span.html#aab4dda04fc0654b91e0829e17fb9d59d',1,'wxTimeSpan']]],
+  ['minacumrgba',['MinAcumRGBA',['../classwx_g_l_attributes.html#ad85c13eead96b8abaa5b50f2057f6316',1,'wxGLAttributes']]],
   ['minimizebutton',['MinimizeButton',['../classwx_aui_pane_info.html#a99aee8968a56af51780f78bcc4752cc8',1,'wxAuiPaneInfo']]],
+  ['minorversion',['MinorVersion',['../classwx_g_l_context_attrs.html#a1acea1a1e0c8f7d54a0c46093bc8914c',1,'wxGLContextAttrs']]],
+  ['minrgba',['MinRGBA',['../classwx_g_l_attributes.html#a9fa858e5227677156a67b9577c47ca7e',1,'wxGLAttributes']]],
   ['minsize',['MinSize',['../classwx_aui_pane_info.html#a67cf6e2c79120febdd32c6156eeddd54',1,'wxAuiPaneInfo::MinSize(const wxSize &amp;size)'],['../classwx_aui_pane_info.html#a1207db6a7a30a58ca5b720343f75db9d',1,'wxAuiPaneInfo::MinSize(int x, int y)']]],
   ['minute',['Minute',['../classwx_time_span.html#af2c88d43853d1168eee6f816b3aafcb3',1,'wxTimeSpan']]],
   ['minutes',['Minutes',['../classwx_time_span.html#ac1207a105513060a4ce39b5f6b4fe6d1',1,'wxTimeSpan']]],
@@ -175,7 +176,10 @@ var searchData=
   ['movetopto',['MoveTopTo',['../classwx_rect2_d_double.html#a03029c3211c844fc0764196bfd27bd15',1,'wxRect2DDouble::MoveTopTo()'],['../classwx_rect2_d_int.html#a0b353fdf7166552b836eb530526feaba',1,'wxRect2DInt::MoveTopTo()']]],
   ['moveup',['MoveUp',['../classwx_rich_text_ctrl.html#abe6115be0c8bbf5a3d740e17ea2f09c7',1,'wxRichTextCtrl']]],
   ['moving',['Moving',['../classwx_mouse_event.html#a4ba54065ea560c30d59fc38cec077c1f',1,'wxMouseEvent']]],
+  ['mswgethandle',['MSWGetHandle',['../classwx_thread.html#a557af76b380550f08bbcf4a6ec12b2ab',1,'wxThread']]],
   ['mswgetshelldir',['MSWGetShellDir',['../classwx_standard_paths.html#a5a523db5b6aca46154ac76d264d2bb57',1,'wxStandardPaths']]],
   ['mswgetsystemmenu',['MSWGetSystemMenu',['../classwx_top_level_window.html#a503565e9c0a1f37a281b52e1d53029b6',1,'wxTopLevelWindow']]],
+  ['mswgettaskbarbutton',['MSWGetTaskBarButton',['../classwx_frame.html#a854554645446695649922860a9c94ea7',1,'wxFrame']]],
+  ['mswusetoasts',['MSWUseToasts',['../classwx_notification_message.html#a52c56483b083d771de4d0819f4795242',1,'wxNotificationMessage']]],
   ['multiply',['Multiply',['../classwx_date_span.html#a1008611f2389be37786d76d816ffbda1',1,'wxDateSpan::Multiply(int factor) const '],['../classwx_date_span.html#a575ba275ad24b6230b25daa451494ada',1,'wxDateSpan::Multiply(int factor)'],['../classwx_time_span.html#ab515cf02a32b07825ca99a6a99327a5f',1,'wxTimeSpan::Multiply(int n) const '],['../classwx_time_span.html#a3ca6fdcf682d05c27c4be20143404253',1,'wxTimeSpan::Multiply(int n)']]]
 ];
